==> webkit2gtk_2.30.3.orig.tar.xz: webkitgtk-2.30.3/Source/JavaScriptCore/runtime/RegExpGlobalData.h <==
/*
 * Copyright (C) 2019 Apple Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "RegExpCachedResult.h"

namespace JSC {

class JSGlobalObject;

class RegExpGlobalData {
public:
    RegExpCachedResult& cachedResult() { return m_cachedResult; }

    void setMultiline(bool multiline) { m_multiline = multiline; }
    bool multiline() const { return m_multiline; }

    void setInput(JSGlobalObject*, JSString*);
    JSString* input() { return m_cachedResult.input(); }

    void visitAggregate(SlotVisitor&);

    JSValue getBackref(JSGlobalObject*, unsigned);
    JSValue getLastParen(JSGlobalObject*);
    JSValue getLeftContext(JSGlobalObject*);
    JSValue getRightContext(JSGlobalObject*);

    MatchResult performMatch(JSGlobalObject*, RegExp*, JSString*, const String&, int startOffset, int** ovector);
    MatchResult performMatch(JSGlobalObject*, RegExp*, JSString*, const String&, int startOffset);
    void recordMatch(VM&, JSGlobalObject*, RegExp*, JSString*, const MatchResult&);

    static ptrdiff_t offsetOfCachedResult() { return OBJECT_OFFSETOF(RegExpGlobalData, m_cachedResult); }

private:
    RegExpCachedResult m_cachedResult;
    bool m_multiline { false };
    Vector<int> m_ovector;
};

}

==> webkit2gtk_2.47.90.orig.tar.xz: webkitgtk-2.47.90/Source/JavaScriptCore/runtime/RegExpGlobalData.h <==
/*
 * Copyright (C) 2019-2021 Apple Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "RegExpCachedResult.h"
#include "RegExpSubstringGlobalAtomCache.h"

namespace JSC {

class JSGlobalObject;

class RegExpGlobalData {
public:
    RegExpCachedResult& cachedResult() { return m_cachedResult; }

    void setMultiline(bool multiline) { m_multiline = multiline; }
    bool multiline() const { return m_multiline; }

    void setInput(JSGlobalObject*, JSString*);
    JSString* input() { return m_cachedResult.input(); }

    DECLARE_VISIT_AGGREGATE;

    JSValue getBackref(JSGlobalObject*, unsigned);
    JSValue getLastParen(JSGlobalObject*);
    JSValue getLeftContext(JSGlobalObject*);
    JSValue getRightContext(JSGlobalObject*);

    MatchResult performMatch(JSGlobalObject*, RegExp*, JSString*, StringView, int startOffset, int** ovector);
    MatchResult performMatch(JSGlobalObject*, RegExp*, JSString*, StringView, int startOffset);
    void recordMatch(VM&, JSGlobalObject*, RegExp*, JSString*, const MatchResult&);

    static constexpr ptrdiff_t offsetOfCachedResult() { return OBJECT_OFFSETOF(RegExpGlobalData, m_cachedResult); }

    const Vector<int>& ovector() const { return m_ovector; }

    inline MatchResult matchResult() const;
    void resetResultFromCache(JSGlobalObject* owner, RegExp*, JSString*, MatchResult, Vector<int>&&);

    RegExpSubstringGlobalAtomCache& substringGlobalAtomCache() { return m_substringGlobalAtomCache; }

private:
    RegExpCachedResult m_cachedResult;
    RegExpSubstringGlobalAtomCache m_substringGlobalAtomCache;
    bool m_multiline { false };
    Vector<int> m_ovector;
};

}
